( cd opt/kde/share/doc/HTML/hu/kformula ; rm -rf common )
( cd opt/kde/share/doc/HTML/hu/kformula ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
( cd opt/kde/share/doc/HTML/hu/koshell ; rm -rf common )
( cd opt/kde/share/doc/HTML/hu/koshell ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
( cd opt/kde/share/doc/HTML/hu/thesaurus ; rm -rf common )
( cd opt/kde/share/doc/HTML/hu/thesaurus ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
